==> manifold-sql-rt-2023.1.21-sources.jar: manifold/sql/rt/impl/accessors/DoubleValueAccessor.java <==
/*
 * Copyright (c) 2023 - Manifold Systems LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package manifold.sql.rt.impl.accessors;

import manifold.sql.rt.api.BaseElement;
import manifold.sql.rt.api.ValueAccessor;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

public class DoubleValueAccessor implements ValueAccessor
{
  @Override
  public int getJdbcType()
  {
    return Types.DOUBLE;
  }

  @Override
  public Class<?> getJavaType( BaseElement elem )
  {
    return elem.canBeNull() ? Double.class : double.class;
  }

  @Override
  public Double getRowValue( ResultSet rs, BaseElement elem ) throws SQLException
  {
    double value = rs.getDouble( elem.getPosition() );
    return value == 0 && rs.wasNull() ? null : value;
  }

  @Override
  public void setParameter( PreparedStatement ps, int pos, Object value ) throws SQLException
  {
    if( value == null )
    {
      ps.setNull( pos, getJdbcType() );
    }
    else if( value instanceof Number )
    {
      ps.setDouble( pos, ((Number)value).doubleValue() );
    }
    else
    {
      ps.setObject( pos, value, getJdbcType() );
    }
  }
}

==> manifold-sql-rt-2024.1.14-sources.jar: manifold/sql/rt/impl/accessors/DoubleValueAccessor.java <==
/*
 * Copyright (c) 2023 - Manifold Systems LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package manifold.sql.rt.impl.accessors;

import manifold.sql.rt.api.BaseElement;
import manifold.sql.rt.api.ColumnInfo;
import manifold.sql.rt.api.ValueAccessor;

import java.sql.*;

public class DoubleValueAccessor implements ValueAccessor
{
  @Override
  public int getJdbcType()
  {
    return Types.DOUBLE;
  }

  @Override
  public Class<?> getJavaType( BaseElement elem )
  {
    return elem.canBeNull() ? Double.class : double.class;
  }

  @Override
  public Double getRowValue( ResultSet rs, BaseElement elem ) throws SQLException
  {
    double value = rs.getDouble( elem.getPosition() );
    return value == 0 && rs.wasNull() ? null : value;
  }

  @Override
  public String getParameterExpression( DatabaseMetaData metaData, Object value, ColumnInfo ci )
  {
    if( ci.getSqlType().equalsIgnoreCase( "money" ) ) // postgres wonk
    {
      return value == null ? "NULL" : "CAST('" + value + "' as money)";
    }
    return ValueAccessor.super.getParameterExpression( metaData, value, ci );
  }

  @Override
  public void setParameter( PreparedStatement ps, int pos, Object value ) throws SQLException
  {
    if( value == null )
    {
      ps.setNull( pos, getJdbcType() );
    }
    else if( value instanceof Number )
    {
      ps.setDouble( pos, ((Number)value).doubleValue() );
    }
    else
    {
      ps.setObject( pos, value, getJdbcType() );
    }
  }
}
